==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/product_image_lists.lang.inc.php <==
<?php
/* --------------------------------------------------------------
  product_image_lists.lang.inc.php 2020-02-04
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2020 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------*/

$t_language_text_section_content_array = [
    
    'CONTROLLER_MESSAGE_MISSING_LIST_NAME'           => 'Es wurde kein Listen Name gesendet',
    'CONTROLLER_MESSAGE_LIST_USED_BY_COMBI'          => 'Diese Liste wird von einer Kombination verwendet',
    'CONTROLLER_MESSAGE_LIST_USED_BY_ATTRIBUTE'      => 'Diese Liste wird von einem Attribut verwendet',
    'CONTROLLER_MESSAGE_LIST_ADDED'                  => 'Die Bilderliste wurde erfolgreich hinzugefügt',
    'CONTROLLER_MESSAGE_LIST_DELETED'                => 'Die Bilderliste wurde erfolgreich gelöscht',
    'CONTROLLER_MESSAGE_LIST_NAME_UPDATED'           => 'Der Name der Bilderliste wurde erfolgreich aktualisiert',
    'CONTROLLER_MESSAGE_IMAGE_ADDED'                 => 'Bild wurde erfolgreich hinzugefügt',
    'CONTROLLER_MESSAGE_IMAGES_DELETED'              => 'Bilder wurden erfolgreich gelöscht',
    'CONTROLLER_MESSAGE_IMAGES_SORTED'               => 'Bilder wurden erfolgreich sortiert',
    'CONTROLLER_MESSAGE_IMAGE_TEXT_UPDATED'          => 'Bildtext wurde erfolgreich aktualisiert',
    'CONTROLLER_MESSAGE_INVALID_REQUEST_METHOD'      => 'Ungültige Anforderungsmethode',
    'CONTROLLER_MESSAGE_INVALID_JSON_INPUT'          => 'Ungültige JSON-Eingabe',
    'CONTROLLER_MESSAGE_MISSING_JSON_REQUIRED_INPUT' => 'Fehlende erforderliche Eingabe',


    /**
     * ADMIN
     */
    'CREATE_BUTTON'                   => 'Erstellen',
    'NEW_COLLECTION_BUTTON'           => 'Neue Kollektion',
    'SELECT_COLLECTION_BUTTON'        => 'Kollektion auswählen',
    'ADD_IMAGE_BUTTON'                => 'Bild hinzufügen',
    'COLLECTION_NAME_PLACEHOLDER'     => 'Sammlungsname eingeben',
    'MAIN_IMAGE_LABEL'                => 'Hauptbild',
    'MODAL_SUCCESS_TEXT'              => 'Erfolg',
    'MODAL_ERROR_TEXT'                => 'Fehler',
    'RESPONSIVE_FILEMANAGER_REQUIRED' => 'Der Responsive File Manager wird benötigt',

    /**
     * MODAL GENERAL
     */
    'MODAL_SAVE_BUTTON'   => 'Speichern',
    'MODAL_CANCEL_BUTTON' => 'Abbrechen',
    'MODAL_YES_BUTTON'    => 'Ja',
    'MODAL_NO_BUTTON'     => 'Nein',

    /*
     * MODAL: EDIT IMAGE
     */
    'MODAL_EDIT_IMAGE_TITLE' => 'Bild bearbeiten',
    'MODAL_EDIT_IMAGE_TITLE_LABEL' => 'Bildtitel',
    'MODAL_EDIT_IMAGE_ALT_TITLE_LABEL' => 'Alternativer Text',

    /*
     * MODAL: EDIT COLLECTION
     */
    'MODAL_EDIT_COLLECTION_TITLE' => 'Sammlungsname bearbeiten',
    'MODAL_EDIT_COLLECTION_NAME_LABEL' => 'Name',

    /*
     * MODAL: CONFIRM
     */
    'MODAL_CONFIRM_TITLE' => 'Achtung',
    'MODAL_CONFIRM_BODY'  => 'Sind Sie sicher, dass Sie diese Operation durchführen wollen?',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/product_image_lists.lang.inc.php <==
<?php
/* --------------------------------------------------------------
  product_image_lists.lang.inc.php 2020-02-04
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2020 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------*/

$t_language_text_section_content_array = [
    
    'CONTROLLER_MESSAGE_MISSING_LIST_NAME'           => 'Es wurde kein Listen Name gesendet',
    'CONTROLLER_MESSAGE_LIST_USED_BY_COMBI'          => 'Diese Liste wird von einer Kombination verwendet',
    'CONTROLLER_MESSAGE_LIST_USED_BY_ATTRIBUTE'      => 'Diese Liste wird von einem Attribut verwendet',
    'CONTROLLER_MESSAGE_LIST_ADDED'                  => 'Die Bilderliste wurde erfolgreich hinzugefügt',
    'CONTROLLER_MESSAGE_LIST_DELETED'                => 'Die Bilderliste wurde erfolgreich gelöscht',
    'CONTROLLER_MESSAGE_LIST_NAME_UPDATED'           => 'Der Name der Bilderliste wurde erfolgreich aktualisiert',
    'CONTROLLER_MESSAGE_IMAGE_ADDED'                 => 'Bild wurde erfolgreich hinzugefügt',
    'CONTROLLER_MESSAGE_IMAGES_DELETED'              => 'Bilder wurden erfolgreich gelöscht',
    'CONTROLLER_MESSAGE_IMAGES_SORTED'               => 'Bilder wurden erfolgreich sortiert',
    'CONTROLLER_MESSAGE_IMAGE_TEXT_UPDATED'          => 'Bildtext wurde erfolgreich aktualisiert',
    'CONTROLLER_MESSAGE_INVALID_REQUEST_METHOD'      => 'Ungültige Anforderungsmethode',
    'CONTROLLER_MESSAGE_INVALID_JSON_INPUT'          => 'Ungültige JSON-Eingabe',
    'CONTROLLER_MESSAGE_MISSING_JSON_REQUIRED_INPUT' => 'Fehlende erforderliche Eingabe',


    /**
     * ADMIN
     */
    'CREATE_BUTTON'                   => 'Erstellen',
    'NEW_COLLECTION_BUTTON'           => 'Neue Kollektion',
    'SELECT_COLLECTION_BUTTON'        => 'Kollektion auswählen',
    'ADD_IMAGE_BUTTON'                => 'Bild hinzufügen',
    'COLLECTION_NAME_PLACEHOLDER'     => 'Sammlungsname eingeben',
    'MAIN_IMAGE_LABEL'                => 'Hauptbild',
    'MODAL_SUCCESS_TEXT'              => 'Erfolg',
    'MODAL_ERROR_TEXT'                => 'Fehler',
    'RESPONSIVE_FILEMANAGER_REQUIRED' => 'Der Responsive File Manager wird benötigt',

    /**
     * MODAL GENERAL
     */
    'MODAL_SAVE_BUTTON'   => 'Speichern',
    'MODAL_CANCEL_BUTTON' => 'Abbrechen',
    'MODAL_YES_BUTTON'    => 'Ja',
    'MODAL_NO_BUTTON'     => 'Nein',

    /*
     * MODAL: EDIT IMAGE
     */
    'MODAL_EDIT_IMAGE_TITLE' => 'Bild bearbeiten',
    'MODAL_EDIT_IMAGE_TITLE_LABEL' => 'Bildtitel',
    'MODAL_EDIT_IMAGE_ALT_TITLE_LABEL' => 'Alternativer Text',

    /*
     * MODAL: EDIT COLLECTION
     */
    'MODAL_EDIT_COLLECTION_TITLE' => 'Sammlungsname bearbeiten',
    'MODAL_EDIT_COLLECTION_NAME_LABEL' => 'Name',

    /*
     * MODAL: CONFIRM
     */
    'MODAL_CONFIRM_TITLE' => 'Achtung',
    'MODAL_CONFIRM_BODY'  => 'Bist du sicher, dass du diese Operation durchführen willst?',
];
